using System;
using System.Text.Json.Serialization;
namespace concerto.metamodel {
   using concerto;
   class TypeIdentifier : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.TypeIdentifier";
      public string name { get; set; }
      public string fullyQualifiedName { get; set; }
   }
   abstract class DecoratorLiteral : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorLiteral";
   }
   class DecoratorString : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorString";
      public string value { get; set; }
   }
   class DecoratorNumber : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorNumber";
      public float value { get; set; }
   }
   class DecoratorBoolean : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorBoolean";
      public bool value { get; set; }
   }
   class DecoratorTypeReference : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorTypeReference";
      public TypeIdentifier type { get; set; }
      public bool isArray { get; set; }
   }
   class Decorator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.Decorator";
      public string name { get; set; }
      public DecoratorLiteral[] arguments { get; set; }
   }
   class Identified : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.Identified";
   }
   class IdentifiedBy : Identified {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IdentifiedBy";
      public string name { get; set; }
   }
   class EnumDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.EnumDeclaration";
      public string name { get; set; }
      public EnumFieldDeclaration[] fields { get; set; }
   }
   class EnumFieldDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.EnumFieldDeclaration";
      public string name { get; set; }
      public Decorator[] decorators { get; set; }
   }
   abstract class ClassDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ClassDeclaration";
      public string name { get; set; }
      public Decorator[] decorators { get; set; }
      public bool isAbstract { get; set; }
      public Identified identified { get; set; }
      public TypeIdentifier superType { get; set; }
      public FieldDeclaration[] fields { get; set; }
   }
   class AssetDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.AssetDeclaration";
   }
   class ParticipantDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ParticipantDeclaration";
   }
   class TransactionDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.TransactionDeclaration";
   }
   class EventDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.EventDeclaration";
   }
   class ConceptDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ConceptDeclaration";
   }
   abstract class FieldDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.FieldDeclaration";
      public string name { get; set; }
      public bool isArray { get; set; }
      public bool isOptional { get; set; }
      public Decorator[] decorators { get; set; }
   }
   class RelationshipDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.RelationshipDeclaration";
      public TypeIdentifier type { get; set; }
   }
   class ObjectFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ObjectFieldDeclaration";
      public string defaultValue { get; set; }
      public TypeIdentifier type { get; set; }
   }
   class BooleanFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.BooleanFieldDeclaration";
      public bool defaultValue { get; set; }
   }
   class DateTimeFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DateTimeFieldDeclaration";
   }
   class StringFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.StringFieldDeclaration";
      public string defaultValue { get; set; }
      public StringRegexValidator validator { get; set; }
   }
   class StringRegexValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.StringRegexValidator";
      public string regex { get; set; }
   }
   class DoubleFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DoubleFieldDeclaration";
      public float defaultValue { get; set; }
      public DoubleDomainValidator validator { get; set; }
   }
   class DoubleDomainValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DoubleDomainValidator";
      public float lower { get; set; }
      public float upper { get; set; }
   }
   class IntegerFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IntegerFieldDeclaration";
      public int defaultValue { get; set; }
      public IntegerDomainValidator validator { get; set; }
   }
   class IntegerDomainValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IntegerDomainValidator";
      public int lower { get; set; }
      public int upper { get; set; }
   }
   class LongFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.LongFieldDeclaration";
      public long defaultValue { get; set; }
      public LongDomainValidator validator { get; set; }
   }
   class LongDomainValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.LongDomainValidator";
      public long lower { get; set; }
      public long upper { get; set; }
   }
   abstract class Import : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.Import";
      public string namespace { get; set; }
      public string uri { get; set; }
   }
   class ImportAll : Import {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ImportAll";
   }
   class ImportType : Import {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ImportType";
      public string name { get; set; }
   }
   class ModelFile : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ModelFile";
      public string namespace { get; set; }
      public Import[] imports { get; set; }
      public EnumDeclaration[] enumDeclarations { get; set; }
      public ClassDeclaration[] classDeclarations { get; set; }
   }
}
